Examples
========

These examples can be found in the ``<nengo-dl>/docs/examples`` directory
(where ``<nengo-dl>`` is the location of the NengoDL package).  The examples
are IPython/Jupyter notebooks; if you would like to run them yourself, refer to
the
`Jupyter documentation <http://jupyter-notebook.readthedocs.io/en/latest/>`_.

.. toctree::
    :maxdepth: 1

    examples/nef_init
    examples/pretrained_model
    examples/spiking_mnist
    examples/spa_retrieval
    examples/spa_memory
